@@ -29,12 +29,21 @@
 class ResourceLoader {
 
 	/* Protected Static Members */
-	protected static $filterCacheVersion = 4;
+	protected static $filterCacheVersion = 7;
+	protected static $requiredSourceProperties = array( 'loadScript' );
 
 	/** Array: List of module name/ResourceLoaderModule object pairs */
 	protected $modules = array();
+
 	/** Associative array mapping module name to info associative array */
 	protected $moduleInfos = array();
+ 
+	/** Associative array mapping framework ids to a list of names of test suite modules */
+	/** like array( 'qunit' => array( 'mediawiki.tests.qunit.suites', 'ext.foo.tests', .. ), .. ) */
+	protected $testModuleNames = array();
+
+	/** array( 'source-id' => array( 'loadScript' => 'http://.../load.php' ) ) **/
+	protected $sources = array();
 
 	/* Protected Methods */
 
@@ -164,7 +173,7 @@ class ResourceLoader {
 			$cache->set( $key, $result );
 		} catch ( Exception $exception ) {
 			// Return exception as a comment
-			$result = "/*\n{$exception->__toString()}\n*/\n";
+			$result = $this->makeComment( $exception->__toString() );
 		}
 
 		wfProfileOut( __METHOD__ );
@@ -178,16 +187,27 @@ class ResourceLoader {
 	 * Registers core modules and runs registration hooks.
 	 */
 	public function __construct() {
-		global $IP, $wgResourceModules;
+		global $IP, $wgResourceModules, $wgResourceLoaderSources, $wgLoadScript, $wgEnableJavaScriptTest;
 
 		wfProfileIn( __METHOD__ );
 
+		// Add 'local' source first
+		$this->addSource( 'local', array( 'loadScript' => $wgLoadScript, 'apiScript' => wfScript( 'api' ) ) );
+
+		// Add other sources
+		$this->addSource( $wgResourceLoaderSources );
+
 		// Register core modules
 		$this->register( include( "$IP/resources/Resources.php" ) );
 		// Register extension modules
 		wfRunHooks( 'ResourceLoaderRegisterModules', array( &$this ) );
 		$this->register( $wgResourceModules );
 
+		if ( $wgEnableJavaScriptTest === true ) {
+			$this->registerTestModules();
+		}
+
+
 		wfProfileOut( __METHOD__ );
 	}
 
@@ -208,49 +228,114 @@ class ResourceLoader {
 		wfProfileIn( __METHOD__ );
 
 		// Allow multiple modules to be registered in one call
-		if ( is_array( $name ) ) {
-			foreach ( $name as $key => $value ) {
-				$this->register( $key, $value );
-			}
-			wfProfileOut( __METHOD__ );
-			return;
-		}
-
-		// Disallow duplicate registrations
-		if ( isset( $this->moduleInfos[$name] ) ) {
-			// A module has already been registered by this name
-			throw new MWException(
-				'ResourceLoader duplicate registration error. ' .
-				'Another module has already been registered as ' . $name
-			);
-		}
-
-		// Check $name for illegal characters
-		if ( preg_match( '/[|,!]/', $name ) ) {
-			throw new MWException( "ResourceLoader module name '$name' is invalid. Names may not contain pipes (|), commas (,) or exclamation marks (!)" );
-		}
-
-		// Attach module
-		if ( is_object( $info ) ) {
-			// Old calling convention
-			// Validate the input
-			if ( !( $info instanceof ResourceLoaderModule ) ) {
-				throw new MWException( 'ResourceLoader invalid module error. ' .
-					'Instances of ResourceLoaderModule expected.' );
+		$registrations = is_array( $name ) ? $name : array( $name => $info );
+		foreach ( $registrations as $name => $info ) {
+			// Disallow duplicate registrations
+			if ( isset( $this->moduleInfos[$name] ) ) {
+				// A module has already been registered by this name
+				throw new MWException(
+					'ResourceLoader duplicate registration error. ' .
+					'Another module has already been registered as ' . $name
+				);
 			}
 
-			$this->moduleInfos[$name] = array( 'object' => $info );
-			$info->setName( $name );
-			$this->modules[$name] = $info;
-		} else {
-			// New calling convention
-			$this->moduleInfos[$name] = $info;
+			// Check $name for illegal characters
+			if ( preg_match( '/[|,!]/', $name ) ) {
+				throw new MWException( "ResourceLoader module name '$name' is invalid. Names may not contain pipes (|), commas (,) or exclamation marks (!)" );
+			}
+
+			// Attach module
+			if ( is_object( $info ) ) {
+				// Old calling convention
+				// Validate the input
+				if ( !( $info instanceof ResourceLoaderModule ) ) {
+					throw new MWException( 'ResourceLoader invalid module error. ' .
+						'Instances of ResourceLoaderModule expected.' );
+				}
+
+				$this->moduleInfos[$name] = array( 'object' => $info );
+				$info->setName( $name );
+				$this->modules[$name] = $info;
+			} else {
+				// New calling convention
+				$this->moduleInfos[$name] = $info;
+			}
 		}
 
 		wfProfileOut( __METHOD__ );
 	}
 
- 	/**
+	/**
+	 */
+	public function registerTestModules() {
+		global $IP, $wgEnableJavaScriptTest;
+
+		if ( $wgEnableJavaScriptTest !== true ) {
+			throw new MWException( 'Attempt to register JavaScript test modules but <tt>$wgEnableJavaScriptTest</tt> is false. Edit your <tt>LocalSettings.php</tt> to enable it.' );
+		}
+
+		wfProfileIn( __METHOD__ );
+
+		// Get core test suites
+		$testModules = array();
+		$testModules['qunit'] = include( "$IP/tests/qunit/QUnitTestResources.php" );
+		// Get other test suites (e.g. from extensions)
+		wfRunHooks( 'ResourceLoaderTestModules', array( &$testModules, &$this ) );
+
+		// Add the testrunner (which configures QUnit) to the dependencies.
+		// Since it must be ready before any of the test suites are executed.
+		foreach( $testModules['qunit'] as $moduleName => $moduleProps ) {
+			$testModules['qunit'][$moduleName]['dependencies'][] = 'mediawiki.tests.qunit.testrunner';
+		}
+
+		foreach( $testModules as $id => $names ) {
+			// Register test modules
+			$this->register( $testModules[$id] );
+
+			// Keep track of their names so that they can be loaded together
+			$this->testModuleNames[$id] = array_keys( $testModules[$id] );
+		}
+
+		wfProfileOut( __METHOD__ );
+	}
+
+	/**
+	 * Add a foreign source of modules.
+	 *
+	 * Source properties:
+	 * 'loadScript': URL (either fully-qualified or protocol-relative) of load.php for this source
+	 *
+	 * @param $id Mixed: source ID (string), or array( id1 => props1, id2 => props2, ... )
+	 * @param $properties Array: source properties
+	 */
+	public function addSource( $id, $properties = null) {
+		// Allow multiple sources to be registered in one call
+		if ( is_array( $id ) ) {
+			foreach ( $id as $key => $value ) {
+				$this->addSource( $key, $value );
+			}
+			return;
+		}
+
+		// Disallow duplicates
+		if ( isset( $this->sources[$id] ) ) {
+			throw new MWException(
+				'ResourceLoader duplicate source addition error. ' .
+				'Another source has already been registered as ' . $id
+			);
+		}
+
+		// Validate properties
+		foreach ( self::$requiredSourceProperties as $prop ) {
+			if ( !isset( $properties[$prop] ) ) {
+				throw new MWException( "Required property $prop missing from source ID $id" );
+			}
+		}
+
+		$this->sources[$id] = $properties;
+	}
+
+	/**
 	 * Get a list of module names
 	 *
 	 * @return Array: List of module names
@@ -258,6 +343,25 @@ class ResourceLoader {
 	public function getModuleNames() {
 		return array_keys( $this->moduleInfos );
 	}
+ 
+ 	/**
+	 * Get a list of test module names for one (or all) frameworks.
+	 * If the given framework id is unknkown, or if the in-object variable is not an array,
+	 * then it will return an empty array.
+	 *
+	 * @param $framework String: Optional. Get only the test module names for one
+	 * particular framework.
+	 * @return Array
+	 */
+	public function getTestModuleNames( $framework = 'all' ) {
+		if ( $framework == 'all' ) {
+			return $this->testModuleNames;
+		} elseif ( isset( $this->testModuleNames[$framework] ) && is_array( $this->testModuleNames[$framework] ) ) {
+			return $this->testModuleNames[$framework];
+		} else {
+			return array();
+		}
+	}
 
 	/**
 	 * Get the ResourceLoaderModule object for a given module name.
@@ -291,13 +395,30 @@ class ResourceLoader {
 		return $this->modules[$name];
 	}
 
+	/**
+	 * Get the list of sources
+	 *
+	 * @return Array: array( id => array of properties, .. )
+	 */
+	public function getSources() {
+		return $this->sources;
+	}
+
 	/**
 	 * Outputs a response to a resource load-request, including a content-type header.
 	 *
 	 * @param $context ResourceLoaderContext: Context in which a response should be formed
 	 */
 	public function respond( ResourceLoaderContext $context ) {
-		global $wgResourceLoaderMaxage, $wgCacheEpoch;
+		global $wgCacheEpoch, $wgUseFileCache;
+
+		// Use file cache if enabled and available...
+		if ( $wgUseFileCache ) {
+			$fileCache = ResourceFileCache::newFromContext( $context );
+			if ( $this->tryRespondFromFileCache( $fileCache, $context ) ) {
+				return; // output handled
+			}
+		}
 
 		// Buffer output to catch warnings. Normally we'd use ob_clean() on the
 		// top-level output buffer to clear warnings, but that breaks when ob_gzhandler
@@ -309,62 +430,113 @@ class ResourceLoader {
 		ob_start();
 
 		wfProfileIn( __METHOD__ );
-		$exceptions = '';
+		$errors = '';
 
 		// Split requested modules into two groups, modules and missing
 		$modules = array();
 		$missing = array();
 		foreach ( $context->getModules() as $name ) {
 			if ( isset( $this->moduleInfos[$name] ) ) {
+				$module = $this->getModule( $name );
+				// Do not allow private modules to be loaded from the web.
+				// This is a security issue, see bug 34907.
+				if ( $module->getGroup() === 'private' ) {
+					$errors .= $this->makeComment( "Cannot show private module \"$name\"" );
+					continue;
+				}
 				$modules[$name] = $this->getModule( $name );
 			} else {
 				$missing[] = $name;
 			}
 		}
 
-		// If a version wasn't specified we need a shorter expiry time for updates
-		// to propagate to clients quickly
-		if ( is_null( $context->getVersion() ) ) {
-			$maxage  = $wgResourceLoaderMaxage['unversioned']['client'];
-			$smaxage = $wgResourceLoaderMaxage['unversioned']['server'];
-		}
-		// If a version was specified we can use a longer expiry time since changing
-		// version numbers causes cache misses
-		else {
-			$maxage  = $wgResourceLoaderMaxage['versioned']['client'];
-			$smaxage = $wgResourceLoaderMaxage['versioned']['server'];
-		}
-
 		// Preload information needed to the mtime calculation below
 		try {
 			$this->preloadModuleInfo( array_keys( $modules ), $context );
 		} catch( Exception $e ) {
 			// Add exception to the output as a comment
-			$exceptions .= "/*\n{$e->__toString()}\n*/\n";
+			$errors .= $this->makeComment( $e->__toString() );
 		}
 
 		wfProfileIn( __METHOD__.'-getModifiedTime' );
 
-		$private = false;
 		// To send Last-Modified and support If-Modified-Since, we need to detect
 		// the last modified time
 		$mtime = wfTimestamp( TS_UNIX, $wgCacheEpoch );
 		foreach ( $modules as $module ) {
+			/**
+			 * @var $module ResourceLoaderModule
+			 */
 			try {
-				// Bypass Squid and other shared caches if the request includes any private modules
-				if ( $module->getGroup() === 'private' ) {
-					$private = true;
-				}
 				// Calculate maximum modified time
 				$mtime = max( $mtime, $module->getModifiedTime( $context ) );
 			} catch ( Exception $e ) {
 				// Add exception to the output as a comment
-				$exceptions .= "/*\n{$e->__toString()}\n*/\n";
+				$errors .= $this->makeComment( $e->__toString() );
 			}
 		}
 
 		wfProfileOut( __METHOD__.'-getModifiedTime' );
 
+		// Send content type and cache related headers
+		$this->sendResponseHeaders( $context, $mtime );
+
+		// If there's an If-Modified-Since header, respond with a 304 appropriately
+		if ( $this->tryRespondLastModified( $context, $mtime ) ) {
+			wfProfileOut( __METHOD__ );
+			return; // output handled (buffers cleared)
+		}
+
+		// Generate a response
+		$response = $this->makeModuleResponse( $context, $modules, $missing );
+
+		// Prepend comments indicating exceptions
+		$response = $errors . $response;
+
+		// Capture any PHP warnings from the output buffer and append them to the
+		// response in a comment if we're in debug mode.
+		if ( $context->getDebug() && strlen( $warnings = ob_get_contents() ) ) {
+			$response = $this->makeComment( $warnings ) . $response;
+		}
+
+		// Remove the output buffer and output the response
+		ob_end_clean();
+		echo $response;
+
+		// Save response to file cache unless there are errors
+		if ( isset( $fileCache ) && !$errors && !$missing ) {
+			// Cache single modules...and other requests if there are enough hits
+			if ( ResourceFileCache::useFileCache( $context ) ) {
+				if ( $fileCache->isCacheWorthy() ) {
+					$fileCache->saveText( $response );
+				} else {
+					$fileCache->incrMissesRecent( $context->getRequest() );
+				}
+			}
+		}
+
+		wfProfileOut( __METHOD__ );
+	}
+
+	/**
+	 * Send content type and last modified headers to the client.
+	 * @param $context ResourceLoaderContext
+	 * @param $mtime string TS_MW timestamp to use for last-modified
+	 * @return void
+	 */
+	protected function sendResponseHeaders( ResourceLoaderContext $context, $mtime ) {
+		global $wgResourceLoaderMaxage;
+		// If a version wasn't specified we need a shorter expiry time for updates
+		// to propagate to clients quickly
+		if ( is_null( $context->getVersion() ) ) {
+			$maxage  = $wgResourceLoaderMaxage['unversioned']['client'];
+			$smaxage = $wgResourceLoaderMaxage['unversioned']['server'];
+		// If a version was specified we can use a longer expiry time since changing
+		// version numbers causes cache misses
+		} else {
+			$maxage  = $wgResourceLoaderMaxage['versioned']['client'];
+			$smaxage = $wgResourceLoaderMaxage['versioned']['server'];
+		}
 		if ( $context->getOnly() === 'styles' ) {
 			header( 'Content-Type: text/css; charset=utf-8' );
 		} else {
@@ -376,16 +548,20 @@ class ResourceLoader {
 			header( 'Cache-Control: private, no-cache, must-revalidate' );
 			header( 'Pragma: no-cache' );
 		} else {
-			if ( $private ) {
-				header( "Cache-Control: private, max-age=$maxage" );
-				$exp = $maxage;
-			} else {
-				header( "Cache-Control: public, max-age=$maxage, s-maxage=$smaxage" );
-				$exp = min( $maxage, $smaxage );
-			}
+			header( "Cache-Control: public, max-age=$maxage, s-maxage=$smaxage" );
+			$exp = min( $maxage, $smaxage );
 			header( 'Expires: ' . wfTimestamp( TS_RFC2822, $exp + time() ) );
 		}
+	}
 
+	/**
+	 * If there's an If-Modified-Since header, respond with a 304 appropriately
+	 * and clear out the output buffer. If the client cache is too old then do nothing.
+	 * @param $context ResourceLoaderContext
+	 * @param $mtime string The TS_MW timestamp to check the header against
+	 * @return bool True iff 304 header sent and output handled
+	 */
+	protected function tryRespondLastModified( ResourceLoaderContext $context, $mtime ) {
 		// If there's an If-Modified-Since header, respond with a 304 appropriately
 		// Some clients send "timestamp;length=123". Strip the part after the first ';'
 		// so we get a valid timestamp.
@@ -413,28 +589,66 @@ class ResourceLoader {
 
 				header( 'HTTP/1.0 304 Not Modified' );
 				header( 'Status: 304 Not Modified' );
-				wfProfileOut( __METHOD__ );
-				return;
+				return true;
 			}
 		}
+		return false;
+	}
 
-		// Generate a response
-		$response = $this->makeModuleResponse( $context, $modules, $missing );
-
-		// Prepend comments indicating exceptions
-		$response = $exceptions . $response;
-
-		// Capture any PHP warnings from the output buffer and append them to the
-		// response in a comment if we're in debug mode.
-		if ( $context->getDebug() && strlen( $warnings = ob_get_contents() ) ) {
-			$response = "/*\n$warnings\n*/\n" . $response;
+	/**
+	 * Send out code for a response from file cache if possible
+	 *
+	 * @param $fileCache ObjectFileCache: Cache object for this request URL
+	 * @param $context ResourceLoaderContext: Context in which to generate a response
+	 * @return bool If this found a cache file and handled the response
+	 */
+	protected function tryRespondFromFileCache(
+		ResourceFileCache $fileCache, ResourceLoaderContext $context
+	) {
+		global $wgResourceLoaderMaxage;
+		// Buffer output to catch warnings.
+		ob_start();
+		// Get the maximum age the cache can be
+		$maxage = is_null( $context->getVersion() )
+			? $wgResourceLoaderMaxage['unversioned']['server']
+			: $wgResourceLoaderMaxage['versioned']['server'];
+		// Minimum timestamp the cache file must have
+		$good = $fileCache->isCacheGood( wfTimestamp( TS_MW, time() - $maxage ) );
+		if ( !$good ) {
+			try { // RL always hits the DB on file cache miss...
+				wfGetDB( DB_SLAVE );
+			} catch( DBConnectionError $e ) { // ...check if we need to fallback to cache
+				$good = $fileCache->isCacheGood(); // cache existence check
+			}
 		}
-
-		// Remove the output buffer and output the response
+		if ( $good ) {
+			$ts = $fileCache->cacheTimestamp();
+			// Send content type and cache headers
+			$this->sendResponseHeaders( $context, $ts, false );
+			// If there's an If-Modified-Since header, respond with a 304 appropriately
+			if ( $this->tryRespondLastModified( $context, $ts ) ) {
+				return false; // output handled (buffers cleared)
+			}
+			$response = $fileCache->fetchText();
+			// Capture any PHP warnings from the output buffer and append them to the
+			// response in a comment if we're in debug mode.
+			if ( $context->getDebug() && strlen( $warnings = ob_get_contents() ) ) {
+				$response = "/*\n$warnings\n*/\n" . $response;
+			}
+			// Remove the output buffer and output the response
+			ob_end_clean();
+			echo $response . "\n/* Cached {$ts} */";
+			return true; // cache hit
+		}
+		// Clear buffer
 		ob_end_clean();
-		echo $response;
 
-		wfProfileOut( __METHOD__ );
+		return false; // cache miss
+	}
+
+	protected function makeComment( $text ) {
+		$encText = str_replace( '*/', '* /', $text );
+		return "/*\n$encText\n*/\n";
 	}
 
 	/**
@@ -461,7 +675,7 @@ class ResourceLoader {
 				$blobs = MessageBlobStore::get( $this, $modules, $context->getLanguage() );
 			} catch ( Exception $e ) {
 				// Add exception to the output as a comment
-				$exceptions .= "/*\n{$e->__toString()}\n*/\n";
+				$exceptions .= $this->makeComment( $e->__toString() );
 			}
 		} else {
 			$blobs = array();
@@ -469,6 +683,10 @@ class ResourceLoader {
 
 		// Generate output
 		foreach ( $modules as $name => $module ) {
+			/**
+			 * @var $module ResourceLoaderModule
+			 */
+
 			wfProfileIn( __METHOD__ . '-' . $name );
 			try {
 				$scripts = '';
@@ -507,8 +725,10 @@ class ResourceLoader {
 				switch ( $context->getOnly() ) {
 					case 'scripts':
 						if ( is_string( $scripts ) ) {
+							// Load scripts raw...
 							$out .= $scripts;
 						} elseif ( is_array( $scripts ) ) {
+							// ...except when $scripts is an array of URLs
 							$out .= self::makeLoaderImplementScript( $name, $scripts, array(), array() );
 						}
 						break;
@@ -534,7 +754,7 @@ class ResourceLoader {
 				}
 			} catch ( Exception $e ) {
 				// Add exception to the output as a comment
-				$exceptions .= "/*\n{$e->__toString()}\n*/\n";
+				$exceptions .= $this->makeComment( $e->__toString() );
 
 				// Register module as missing
 				$missing[] = $name;
@@ -674,30 +894,31 @@ class ResourceLoader {
 	 * @param $version Integer: Module version number as a timestamp
 	 * @param $dependencies Array: List of module names on which this module depends
 	 * @param $group String: Group which the module is in.
+	 * @param $source String: Source of the module, or 'local' if not foreign.
 	 * @param $script String: JavaScript code
 	 *
 	 * @return string
 	 */
-	public static function makeCustomLoaderScript( $name, $version, $dependencies, $group, $script ) {
+	public static function makeCustomLoaderScript( $name, $version, $dependencies, $group, $source, $script ) {
 		$script = str_replace( "\n", "\n\t", trim( $script ) );
 		return Xml::encodeJsCall(
-			"( function( name, version, dependencies, group ) {\n\t$script\n} )",
-			array( $name, $version, $dependencies, $group ) );
+			"( function( name, version, dependencies, group, source ) {\n\t$script\n} )",
+			array( $name, $version, $dependencies, $group, $source ) );
 	}
 
 	/**
 	 * Returns JS code which calls mw.loader.register with the given
 	 * parameters. Has three calling conventions:
 	 *
-	 *   - ResourceLoader::makeLoaderRegisterScript( $name, $version, $dependencies, $group ):
+	 *   - ResourceLoader::makeLoaderRegisterScript( $name, $version, $dependencies, $group, $source ):
 	 *       Register a single module.
 	 *
 	 *   - ResourceLoader::makeLoaderRegisterScript( array( $name1, $name2 ) ):
 	 *       Register modules with the given names.
 	 *
 	 *   - ResourceLoader::makeLoaderRegisterScript( array(
-	 *        array( $name1, $version1, $dependencies1, $group1 ),
-	 *        array( $name2, $version2, $dependencies1, $group2 ),
+	 *        array( $name1, $version1, $dependencies1, $group1, $source1 ),
+	 *        array( $name2, $version2, $dependencies1, $group2, $source2 ),
 	 *        ...
 	 *     ) ):
 	 *        Registers modules with the given names and parameters.
@@ -706,18 +927,42 @@ class ResourceLoader {
 	 * @param $version Integer: Module version number as a timestamp
 	 * @param $dependencies Array: List of module names on which this module depends
 	 * @param $group String: group which the module is in.
+	 * @param $source String: source of the module, or 'local' if not foreign
 	 *
 	 * @return string
 	 */
 	public static function makeLoaderRegisterScript( $name, $version = null,
-		$dependencies = null, $group = null )
+		$dependencies = null, $group = null, $source = null )
 	{
 		if ( is_array( $name ) ) {
 			return Xml::encodeJsCall( 'mw.loader.register', array( $name ) );
 		} else {
 			$version = (int) $version > 1 ? (int) $version : 1;
 			return Xml::encodeJsCall( 'mw.loader.register',
-				array( $name, $version, $dependencies, $group ) );
+				array( $name, $version, $dependencies, $group, $source ) );
+		}
+	}
+
+	/**
+	 * Returns JS code which calls mw.loader.addSource() with the given
+	 * parameters. Has two calling conventions:
+	 *
+	 *   - ResourceLoader::makeLoaderSourcesScript( $id, $properties ):
+	 *       Register a single source
+	 *
+	 *   - ResourceLoader::makeLoaderSourcesScript( array( $id1 => $props1, $id2 => $props2, ... ) );
+	 *       Register sources with the given IDs and properties.
+	 *
+	 * @param $id String: source ID
+	 * @param $properties Array: source properties (see addSource())
+	 *
+	 * @return string
+	 */
+	public static function makeLoaderSourcesScript( $id, $properties = null ) {
+		if ( is_array( $id ) ) {
+			return Xml::encodeJsCall( 'mw.loader.addSource', array( $id ) );
+		} else {
+			return Xml::encodeJsCall( 'mw.loader.addSource', array( $id, $properties ) );
 		}
 	}
 
@@ -730,8 +975,7 @@ class ResourceLoader {
 	 * @return string
 	 */
 	public static function makeLoaderConditionalScript( $script ) {
-		$script = str_replace( "\n", "\n\t", trim( $script ) );
-		return "if(window.mw){\n\t$script\n}\n";
+		return "if(window.mw){\n".trim( $script )."\n}";
 	}
 
 	/**
@@ -807,7 +1051,7 @@ class ResourceLoader {
 		$query = self::makeLoaderQuery( $modules, $lang, $skin, $user, $version, $debug,
 			$only, $printable, $handheld, $extraQuery
 		);
-		
+
 		// Prevent the IE6 extension check from being triggered (bug 28840)
 		// by appending a character that's invalid in Windows extensions ('*')
 		return wfExpandUrl( wfAppendQuery( $wgLoadScript, $query ) . '&*', PROTO_RELATIVE );
@@ -842,7 +1086,7 @@ class ResourceLoader {
 			$query['handheld'] = 1;
 		}
 		$query += $extraQuery;
-		
+
 		// Make queries uniform in order
 		ksort( $query );
 		return $query;
