@@ -294,7 +294,6 @@ Pot fabot ripotta este para un [[Special:ListUsers/sysop|administrator]], ya un
 'unexpected'           => 'Ti ma\'antisipa i guinaha: "$1"="$2".',
 'badtitle'             => 'Båba na titulo',
 'viewsource'           => 'Atan i code',
-'viewsourcefor'        => 'para $1',
 'viewsourcetext'       => "Siña un li'e' yan kopia i code ni påhina:",
 'namespaceprotected'   => "Ti nahong nibet-mu petmisu tumulaika i påhina siha ni mafa'na'an '''$1'''.",
 'ns-specialprotected'  => 'Ti siña un tulaika i manespesiat na påhina.',
@@ -446,9 +445,6 @@ Ti siña un usa i ramientan 'e-mail i muna'sesetbi,' solo guåha e-mail address
 Machomma' i ID #$5.
 Pot fabot, na'hålom i ID gi todus i finaisen-mu siha.",
 'blockednoreason'                  => "ti mana'i rason",
-'blockedoriginalsource'            => "Ma'a'annok i code '''$1''' gi papa':",
-'blockededitsource'                => "Ma'a'annok gi papa' i tinige' '''tinilaika-mu''' gi '''$1''':",
-'whitelistedittitle'               => 'Nesesario malogin para tumulaika',
 'whitelistedittext'                => 'Un nesisita ma$1 para tumulaika påhina.',
 'confirmedittext'                  => "Un nesisita un konfotme iyo-mu email åntes di tumulaika påhina.
 Pot fabot po'lo yan konfotme iyo-mu e-mail gi [[Special:Preferences|prifirensia muna'sesetbi]].",
@@ -581,20 +577,11 @@ fana'an guåha attikulo gi [{{fullurl:{{#Special:Log}}/suppress|page={{FULLPAGEN
 'revdelete-unsuppress'        => "Na'suha i chinemma' siha gi tinilaika manmana'lo siha",
 'revdelete-log'               => 'Rason:',
 'revdelete-submit'            => "Na'aplika gi tinilaika ni ma'ayek",
-'revdelete-logentry'          => "ha tulaika i lini'e'on ribision [[$1]]",
-'logdelete-logentry'          => "ha tulaika i lini'e'on kasu [[$1]]",
 'revdelete-success'           => "'''Munhåyan i sinesedi i lini'e'on ribision .'''",
 'logdelete-success'           => "'''Munhåyan i sinesedi i lini'e'on log.'''",
 'revdel-restore'              => "Tulaika i lini'e'on",
 'pagehist'                    => 'Historian påhina',
 'deletedhist'                 => "Historia mana'suha",
-'revdelete-content'           => 'guinaha',
-'revdelete-summary'           => 'tulaika i sumaria',
-'revdelete-uname'             => "nå'an muna'sesetbi",
-'revdelete-hid'               => "manå'na' $1",
-'revdelete-unhid'             => "mana'annok $1",
-'revdelete-log-message'       => '$1 para $2 {{PLURAL:$2|na ribision|na ribision siha}}',
-'logdelete-log-message'       => '$1 para $2 {{PLURAL:$2|na kåsu|na kåsu siha}}',
 
 # Suppression log
 'suppressionlog' => "Log manchinemma'",
@@ -923,7 +910,6 @@ Konfotme fan na este i malago'-mu, na kumonprende hao hiniyong-ña, yan tumattiy
 'actioncomplete'        => 'Funhayan i aksion',
 'deletedtext'           => 'Mana\'suha "$1".
 Chek $2 para i historian muna\'suha gi halacha.',
-'deletedarticle'        => 'Mana\'suha "[[$1]]"',
 'dellogpage'            => "Historian muna'suha",
 'deletecomment'         => 'Rason:',
 'deleteotherreason'     => 'Otru na rason:',
@@ -1026,7 +1012,6 @@ Ayek fan otru nå'an-ña.",
 'talkexists'       => "'''Munhåyan i siniha i påhina mismo, lao ti siña ha kånya i påhinan kombetsasion sa' guåha esta otru ni titulon nuebu.'''",
 'movedto'          => 'makånya para',
 'movetalk'         => 'Kånya i påhinan kombetsasion',
-'1movedto2'        => 'Makånya [[$1]] påra [[$2]]',
 'movelogpage'      => 'Kånya i log',
 'movereason'       => 'Rason:',
 'revertmove'       => 'tulaika tatte',
@@ -1101,7 +1086,7 @@ Ayek fan otru nå'an-ña.",
 
 # Media information
 'file-info-size' => '$1 × $2 na pixel, mineddong atkibu: $3, MIME klåsi: $4',
-'file-nohires'   => "<small>Tåya' mas takhilo' na risolusion.</small>",
+'file-nohires'   => "Tåya' mas takhilo' na risolusion.",
 'svg-long-desc'  => 'Atkibu SVG, $1 × $2 na pixels, mineddong atkibu: $3',
 'show-big-image' => 'Magåhet mineddong-ña',
 
