@@ -7,6 +7,7 @@
  * @ingroup Language
  * @file
  *
+ * @author Deviathan (on dv.wikipedia.org)
  * @author Glacious
  * @author MF-Warburg
  * @author לערי ריינהארט
@@ -263,7 +264,6 @@ $messages = array(
 
 ތިބޭފުޅޭގެ އައި.ޕީ އެޑް ރެސް އަކީ  $3 އެވެ.
 އަދި ބްލޮކް އައި.ޑީ އަކީ #$5 އެވެ.",
-'blockedoriginalsource'    => "'''$1''' މަޒުމޫނުގެ މަސްދަރު ތިރީގައި މި ވަނީ އެވެ:",
 'accmailtitle'             => 'ސިއްރުބަސް ފޮނުވިއްޖެ.',
 'accmailtext'              => '"$1" އަށްޓަކައިވާ ސިއްރު ބަސް $2 އަށް ވަނީ ފޮނުވިފައި',
 'newarticle'               => '(އައު)',
@@ -437,8 +437,6 @@ Also see [[Special:WantedCategories|wanted categories]].',
 'movepagebtn'             => 'ޞަފްޙާގެނަން ބަދަލުކުރައްވާ',
 'articleexists'           => 'ތިޔަ ސުރުހީގައި ކުރީއްސުރެ ވެސް ޞަފްޙައެއް ވޭ، ނުވަތަ ތިޔަ އިހުތިޔާރުކުރެއްވި ނަން ރަނގަޅެއް ނޫން، ވީމާ އެހެން ނަމެއް އިހުތިޔާރުކުރެއްވުން އެދެވިގެންވެއެވެ.',
 'movedto'                 => 'އަށް ބަދަލުކުރެވިފައި',
-'1movedto2'               => '[[$1]] އަށް ނަގުލުކުރެވިފައި [[$2]]',
-'1movedto2_redir'         => '[[$2]] އަށް ނަގުލުކުރެވިއްޖެ [[$1]] މިސްރާބުކުރައްވާ',
 'movelogpagetext'         => 'ތިރީގައި މިވަނީ ނަން/ތަން ބަދަލުކުރެވިފައިވާ ޞަފްޙާތަކުގެ ފިހުރިސްތެކެވެ.',
 'movereason'              => 'ސަބަބު',
 'delete_and_move'         => 'ފޮހެލައްވާފައި އެހެންނަމަކަށްބަދަލުކުރައްވާ',
