@@ -165,7 +165,6 @@ $messages = array(
 'badtitle'       => 'མགོ་མིང་བྱང་ཉེས།',
 'badtitletext'   => 'ཞུ་བ་འབད་ཡོད་པའི་ཤོག་ལེབ་མགོ་མིང་འདི་ ནུས་མེད་ སྟོངམ་ ཡང་ན་ བདེན་མེད་འབྲེལ་མཐུད་ཅན་གྱི་ནང་ཁུལ་-སྐད་ཡིག་ ཡངན་ ནང་ཁུལ་-ཝི་ཀི་མགོ་མིང་ཨིན་པས། དེ་ནང་ མགོ་མིང་ནང་ལུ་ལག་ལེན་འཐབ་མ་བཏུབ་པའི་ཡིག་འབྲུ་གཅིག་ ཡང་ན་ ལེ་ཤ་ཡོདཔ་འོང་།',
 'viewsource'     => 'འབྱུང་ས་སྟོན།',
-'viewsourcefor'  => '$1 གི་',
 'viewsourcetext' => 'ཁྱོད་ཀྱིས་ ཤོག་ལེབ་འདི་གི་འབྱུང་ས་བལྟ་བཏུབ་པའི་ཁར་ འདྲ་བཤུས་ཡང་རྐྱབ་བཏུབ་ཨིན་:',
 
 # Login and logout pages
@@ -485,7 +484,6 @@ $messages = array(
 'actioncomplete'        => 'བྱ་ལས་མཇུག་བསྡུ།',
 'deletedtext'           => '"$1" འདི་ བཏོན་བཀོག་ནུག།
 འཕྲལ་ཁམས་ལུ་བཏོན་བཀོག་མི་ཐོ་གི་དོན་ལུ་ $2 ལུ་བལྟ།',
-'deletedarticle'        => '"[[$1]]" བཏོན་གཏང་ཡོདཔ།',
 'dellogpage'            => 'བཏོན་གཏང་ཡོད་པའི་ལོག།',
 'deletecomment'         => 'རྒྱུ་མཚན:',
 'deleteotherreason'     => 'གཞན་/ཁ་སྐོང་ཅན་གྱི་རྒྱུ་མཚན།',
@@ -586,7 +584,6 @@ $messages = array(
 དེ་ཚུ་ ལག་ཐོག་ལས་མཉམ་བསྡོམས་འབད་གནང་།'''",
 'movedto'          => 'ལུ་སྤོ་བཤུད་འབད།',
 'movetalk'         => 'འབྲེལ་བ་ཡོད་པའི་ཁ་སླབ་ཤོག་ལེབ་ སྤོ་བཤུད་འབད།',
-'1movedto2'        => '[[$1]] འདི་ [[$2]] ལུ་སྤོ་བཤུད་འབད་ཡོདཔ།',
 'movelogpage'      => 'ལོག་སྤོ་བཤུད་འབད།',
 'movereason'       => 'རྒྱུ་མཚན:',
 'revertmove'       => 'རྒྱབ་ལོག།',
@@ -652,7 +649,7 @@ $messages = array(
 
 # Media information
 'file-info-size' => '$1 × $2 པིག་སེལ་  ཡིག་སྣོད་ཀྱི་ཚད་: $3 མའིམ་དབྱེ་བ་: $4',
-'file-nohires'   => '<small>ཧུམ་ཆ་ལེགས་ཤོམ་མིན་འདུག།</small>',
+'file-nohires'   => 'ཧུམ་ཆ་ལེགས་ཤོམ་མིན་འདུག།',
 'svg-long-desc'  => 'ཨེསི་བི་ཇི་ཡིག་སྣོད་  $1 × $2 པིག་སེལསི་ཆུང་སུ་ཅིག་  ཡིག་སྣོད་ཚད་: $3',
 'show-big-image' => 'ཧུམ་ཆ་གང་།',
 
