@@ -9,6 +9,7 @@
  *
  * @author (vinny)
  * @author Homo logos
+ * @author Inego (on jbo.wikipedia.org)
  * @author Malafaya
  * @author OldakQuill
  * @author PierreAbbat
@@ -70,10 +71,14 @@ $messages = array(
 'category-subcat-count'  => "$2 klesi cu vipsi le vi klesi .i $1 vipkle cu ni'a se jarco",
 'category-article-count' => "$2 kibypapri cu cmima le vi klesi .i $1 kibypapri cu ni'a se jarco",
 
+'mytalk'     => 'casnu mi',
+'navigation' => 'ckupau',
+
+# Cologne Blue skin
 'qbedit'        => 'stika',
 'qbpageoptions' => 'ti ckupau',
-'mytalk'        => 'casnu mi',
-'navigation'    => 'ckupau',
+'faq'           => 'FAQ',
+'faqpage'       => 'Project:FAQ',
 
 'errorpagetitle'   => 'fliba',
 'tagline'          => "ra'i {{SITENAME}}",
@@ -96,7 +101,7 @@ $messages = array(
 'views'            => 'Catlu',
 'toolbox'          => 'tutci',
 'otherlanguages'   => 'drata bangu',
-'lastmodifiedat'   => "le vi ckupau rore'u se galfi de'i li $2 $1", # $1 date, $2 time
+'lastmodifiedat'   => "le vi ckupau rore'u se galfi de'i li $2 $1",
 'jumpto'           => 'plipe tyobu:',
 'jumptonavigation' => 'ckupau',
 'jumptosearch'     => 'sisku',
@@ -105,7 +110,6 @@ $messages = array(
 'aboutsite'            => 'About {{SITENAME}}',
 'aboutpage'            => "Project:sera'a",
 'copyright'            => "lo selvau cu gubni ja'i la'o gy. $1 .gy.",
-'copyrightpagename'    => "{{SITENAME}} fukyzifpo'e",
 'copyrightpage'        => "{{ns:project}}:fukyzifpo'e",
 'currentevents'        => "caca'a fasnu",
 'currentevents-url'    => "Project:caca'a fasnu",
@@ -113,8 +117,6 @@ $messages = array(
 'disclaimerpage'       => "Project:kampu nunxusra be lo za'i na fuzme",
 'edithelp'             => 'stika nunsidju',
 'edithelppage'         => 'Help:Editing',
-'faq'                  => 'FAQ',
-'faqpage'              => 'Project:FAQ',
 'mainpage'             => 'Ralju Ckupau',
 'mainpage-description' => 'ralju ckupau',
 'portal'               => 'bende ckupau',
@@ -178,10 +180,11 @@ $messages = array(
 'editingcomment' => 'ca galfi le selcmene be zoi $1 (comment)',
 
 # History pages
-'cur'        => 'cab',
-'last'       => "prula'i",
-'page_first' => 'pamoi',
-'page_last'  => 'fanmo',
+'revisionasof' => "velfarvi de'i $1",
+'cur'          => 'cab',
+'last'         => "prula'i",
+'page_first'   => 'pamoi',
+'page_last'    => 'fanmo',
 
 # Revision deletion
 'rev-delundel' => 'jarco/mipri',
@@ -201,7 +204,7 @@ $messages = array(
 # Preferences page
 'preferences'       => 'zmaselnei',
 'mypreferences'     => 'zmaselnei liste',
-'textboxsize'       => 'ca galfi',
+'prefs-editing'     => 'ca galfi',
 'searchresultshead' => "tu'a le se sisku",
 'savedprefs'        => 'le do zmaselnei pu vreji',
 
@@ -253,9 +256,8 @@ $messages = array(
 'unwatching' => "co'u jundi",
 
 # Delete
-'deletedarticle' => "pu daspo la'e lu [[$1]] li'u",
-'dellogpage'     => 'plivei fi loi nu daspo',
-'deletionlog'    => 'plivei fi loi nu daspo',
+'dellogpage'  => 'plivei fi loi nu daspo',
+'deletionlog' => 'plivei fi loi nu daspo',
 
 # Rollback
 'rollbacklink' => 'lamxru',
@@ -270,6 +272,7 @@ $messages = array(
 'contributions' => 'selstika le pilno',
 'mycontris'     => 'pu selstika mi',
 
+'sp-contributions-talk'   => 'casnu',
 'sp-contributions-submit' => 'sisku',
 
 # What links here
@@ -282,7 +285,6 @@ $messages = array(
 
 # Move page
 'movedto'    => 'te muvdu',
-'1movedto2'  => "le pu se cmene lu [[$1]] li'u cu ca se cmene lu [[$2]] li'u",
 'revertmove' => 'xruti',
 
 # Tooltip help for the actions
