@@ -8,6 +8,7 @@
  * @file
  *
  * @author Kaganer
+ * @author Krinkle
  * @author Xqt
  * @author לערי ריינהארט
  */
@@ -126,6 +127,7 @@ $messages = array(
 'subcategories'                  => 'Unnerabdeeling',
 'category-media-header'          => 'Media in Abdeeling „$1“',
 'category-empty'                 => "''Die Abdeeling hot zu daere Zeit kene Bledder oder Feils.''",
+'hidden-categories'              => '{{PLURAL:$1|Versteckelte Abdeeling|Verstecktelte Abdeelinge}}',
 'category-article-count-limited' => '{{PLURAL:$1|Sell Blatt iss|Selle $1 Bledder sin}} in daer Abdeeling drin:',
 'category-file-count-limited'    => '{{PLURAL:$1|Sell Feil iss|Selle $1 Feils sin}} in daer Abdeeling drin:',
 'listingcontinuesabbrev'         => '(weider)',
@@ -276,6 +278,7 @@ Wenns des net iss, hoscht verleicht en Fehler in de Daadebank gfunne. Bitte meld
 'missingarticle-diff' => '(Unnerschidd zwische Versione: $1, $2)',
 'internalerror'       => 'Interner Fehler',
 'internalerror_info'  => 'Interner Fehler: $1',
+'badtitle'            => 'Tidl net gildich',
 'ns-specialprotected' => 'Besunnere Bledder sinn net zum Ennere.',
 
 # Virus scanner
@@ -425,7 +428,7 @@ Paesswatt fer nau: $2',
 'qbsettings-none' => 'Ken',
 
 # Preferences page
-'preferences'              => 'paerseenlich Profil',
+'preferences'              => 'Paerseenlich Profil',
 'mypreferences'            => 'Mei Uffschtelling',
 'changepassword'           => 'Paesswatt ennere',
 'skin-preview'             => 'Aagucke',
